==> ssp-center-api-0.5.25-mhs-20190709.063225-14-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/MaterialDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class MaterialDto implements Serializable{
	private static final long serialVersionUID = 8180020066933617725L;

	private Long id;

    private Date gmtCreate;

    private Date gmtModified;

    private String title;

    private String content;

    private String pictureType;

    private String pictureGroup;

    private Long msId;

    private String msName;

    private String remark;
    
    private String md5;

    private String designer;

    /**
     * 审核状态
     */
    private Integer auditState;

    /**
     * 审核消息
     */
    private String auditMsg;

    /**
     * 审核图片
     */
    private String auditUrl;

    /**
     * 最后审核提交人
     */
    private Long lastManagerId;

    /**
     * 最后审核提交时间
     */
    private Date submitAuditTime;

    /** 素材开启状态，0：关闭，1：开启，不传：全部 */
    private Integer enableStatus;
    /** 素材定时开关，1：开启，0：关闭 */
    private Integer regularTimeStatus;
    /** 素材定时生效时间 */
    private Long regularTimeStart;
    /** 素材定时失效时间 */
    private Long regularTimeEnd;
    /** 素材媒体定向开关，1：开启，0：关闭 */
    private Integer mediaLimitStatus;
    /** 素材定向的媒体列表 */
    private List<Long> mediaAppIdList;
    /** 素材标签集合 */
    private List<String> tagIdList;

    public String getDesigner() {
        return designer;
    }

    public void setDesigner(String designer) {
        this.designer = designer;
    }

    public String getMd5() {
		return md5;
	}

	public void setMd5(String md5) {
		this.md5 = md5;
	}

	public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title == null ? null : title.trim();
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public String getPictureType() {
        return pictureType;
    }

    public void setPictureType(String pictureType) {
        this.pictureType = pictureType == null ? null : pictureType.trim();
    }

    public String getPictureGroup() {
        return pictureGroup;
    }

    public void setPictureGroup(String pictureGroup) {
        this.pictureGroup = pictureGroup == null ? null : pictureGroup.trim();
    }

    public Long getMsId() {
        return msId;
    }

    public void setMsId(Long msId) {
        this.msId = msId;
    }

    public String getMsName() {
        return msName;
    }

    public void setMsName(String msName) {
        this.msName = msName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    public Integer getAuditState() {
        return auditState;
    }

    public void setAuditState(Integer auditState) {
        this.auditState = auditState;
    }

    public String getAuditMsg() {
        return auditMsg;
    }

    public void setAuditMsg(String auditMsg) {
        this.auditMsg = auditMsg;
    }

    public Long getLastManagerId() {
        return lastManagerId;
    }

    public void setLastManagerId(Long lastManagerId) {
        this.lastManagerId = lastManagerId;
    }

    public Date getSubmitAuditTime() {
        return submitAuditTime;
    }

    public void setSubmitAuditTime(Date submitAuditTime) {
        this.submitAuditTime = submitAuditTime;
    }

    public String getAuditUrl() {
        return auditUrl;
    }

    public void setAuditUrl(String auditUrl) {
        this.auditUrl = auditUrl;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Integer getRegularTimeStatus() {
        return regularTimeStatus;
    }

    public void setRegularTimeStatus(Integer regularTimeStatus) {
        this.regularTimeStatus = regularTimeStatus;
    }

    public Long getRegularTimeStart() {
        return regularTimeStart;
    }

    public void setRegularTimeStart(Long regularTimeStart) {
        this.regularTimeStart = regularTimeStart;
    }

    public Long getRegularTimeEnd() {
        return regularTimeEnd;
    }

    public void setRegularTimeEnd(Long regularTimeEnd) {
        this.regularTimeEnd = regularTimeEnd;
    }

    public Integer getMediaLimitStatus() {
        return mediaLimitStatus;
    }

    public void setMediaLimitStatus(Integer mediaLimitStatus) {
        this.mediaLimitStatus = mediaLimitStatus;
    }

    public List<Long> getMediaAppIdList() {
        return mediaAppIdList;
    }

    public void setMediaAppIdList(List<Long> mediaAppIdList) {
        this.mediaAppIdList = mediaAppIdList;
    }

    public List<String> getTagIdList() {
        return tagIdList;
    }

    public void setTagIdList(List<String> tagIdList) {
        this.tagIdList = tagIdList;
    }
}

==> ssp-center-api-0.5.35-mhs-20190717.113639-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/MaterialDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class MaterialDto implements Serializable{
    private static final long serialVersionUID = 619835347607660768L;

    private Long id;

    private Date gmtCreate;

    private Date gmtModified;

    private String title;

    private String content;

    private String pictureType;

    private String pictureGroup;

    private Long msId;

    private String msName;

    private String remark;
    
    private String md5;

    private String designer;

    /**
     * 审核状态
     */
    private Integer auditState;

    /**
     * 审核消息
     */
    private String auditMsg;

    /**
     * 审核图片
     */
    private String auditUrl;

    /**
     * 最后审核提交人
     */
    private Long lastManagerId;

    /**
     * 最后审核提交时间
     */
    private Date submitAuditTime;

    /** 素材开启状态，0：关闭，1：开启，不传：全部 */
    private Integer enableStatus;
    /** 素材定时开关，1：开启，0：关闭 */
    private Integer regularTimeStatus;
    /** 素材定时生效时间 */
    private Long regularTimeStart;
    /** 素材定时失效时间 */
    private Long regularTimeEnd;
    /** 素材媒体定向开关，1：开启，0：关闭 */
    private Integer mediaLimitStatus;
    /** 素材定向的媒体ID列表 */
    private List<Long> mediaAppIdList;
    /** 素材标签集合 */
    private List<String> tagIdList;
    /** 素材定向的媒体列表 */
    private List<MediaAppDto> mediaAppList;

    public String getDesigner() {
        return designer;
    }

    public void setDesigner(String designer) {
        this.designer = designer;
    }

    public String getMd5() {
		return md5;
	}

	public void setMd5(String md5) {
		this.md5 = md5;
	}

	public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title == null ? null : title.trim();
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public String getPictureType() {
        return pictureType;
    }

    public void setPictureType(String pictureType) {
        this.pictureType = pictureType == null ? null : pictureType.trim();
    }

    public String getPictureGroup() {
        return pictureGroup;
    }

    public void setPictureGroup(String pictureGroup) {
        this.pictureGroup = pictureGroup == null ? null : pictureGroup.trim();
    }

    public Long getMsId() {
        return msId;
    }

    public void setMsId(Long msId) {
        this.msId = msId;
    }

    public String getMsName() {
        return msName;
    }

    public void setMsName(String msName) {
        this.msName = msName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    public Integer getAuditState() {
        return auditState;
    }

    public void setAuditState(Integer auditState) {
        this.auditState = auditState;
    }

    public String getAuditMsg() {
        return auditMsg;
    }

    public void setAuditMsg(String auditMsg) {
        this.auditMsg = auditMsg;
    }

    public Long getLastManagerId() {
        return lastManagerId;
    }

    public void setLastManagerId(Long lastManagerId) {
        this.lastManagerId = lastManagerId;
    }

    public Date getSubmitAuditTime() {
        return submitAuditTime;
    }

    public void setSubmitAuditTime(Date submitAuditTime) {
        this.submitAuditTime = submitAuditTime;
    }

    public String getAuditUrl() {
        return auditUrl;
    }

    public void setAuditUrl(String auditUrl) {
        this.auditUrl = auditUrl;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Integer getRegularTimeStatus() {
        return regularTimeStatus;
    }

    public void setRegularTimeStatus(Integer regularTimeStatus) {
        this.regularTimeStatus = regularTimeStatus;
    }

    public Long getRegularTimeStart() {
        return regularTimeStart;
    }

    public void setRegularTimeStart(Long regularTimeStart) {
        this.regularTimeStart = regularTimeStart;
    }

    public Long getRegularTimeEnd() {
        return regularTimeEnd;
    }

    public void setRegularTimeEnd(Long regularTimeEnd) {
        this.regularTimeEnd = regularTimeEnd;
    }

    public Integer getMediaLimitStatus() {
        return mediaLimitStatus;
    }

    public void setMediaLimitStatus(Integer mediaLimitStatus) {
        this.mediaLimitStatus = mediaLimitStatus;
    }

    public List<Long> getMediaAppIdList() {
        return mediaAppIdList;
    }

    public void setMediaAppIdList(List<Long> mediaAppIdList) {
        this.mediaAppIdList = mediaAppIdList;
    }

    public List<String> getTagIdList() {
        return tagIdList;
    }

    public void setTagIdList(List<String> tagIdList) {
        this.tagIdList = tagIdList;
    }

    public List<MediaAppDto> getMediaAppList() {
        return mediaAppList;
    }

    public void setMediaAppList(List<MediaAppDto> mediaAppList) {
        this.mediaAppList = mediaAppList;
    }
}
